import argparse

import .utils as utils

if __name__ == "__main__":
    print(utils.banner())
    parser = argparse.ArgumentParser(description='anime downloader')
    parser.add_argument('--name', type=str, help='\nWhat anime do you wanna download today:::')
    parser.add_argument("--version", action="version", version="%(prog)s " + str(utils.get_version()),)
    args = parser.parse_args()

    print("\nAll anime are gotten from www.animeout.xyz/")

    anime_name = args.name
    search_result = utils.get_search_result(anime_name)

    print("\nSearch results for", anime_name)
    for i, j in enumerate(search_result):
        print(i + 1, " - " + j["name"])
    choice = int(input("\nWhich one? Enter the number of your choice::: "))

    anime = search_result[choice - 1]
    anime["name"] = "".join([i if i.isalnum() else "-" for i in anime["name"]])
    episodes = utils.get_anime_episodes(anime["url"])

    utils.make_directory(anime["name"])
    print("\nPress CTRL + C to cancel your download at any time")
    for i in episodes:
        download_url = utils.get_download_url(i)
        utils.download_episode(anime["name"], download_url)

    print("\nFinished downloading all episodes of", anime["name"])



import os
import requests
import wget
from bs4 import BeautifulSoup


def banner():
    """
        Banner
    """
    banner_ascii = """
  /$$$$$$            /$$                         /$$   /$$
 /$$__  $$          |__/                        | $$  / $$
| $$  \ $$ /$$$$$$$  /$$ /$$$$$$/$$$$   /$$$$$$ |  $$/ $$/
| $$$$$$$$| $$__  $$| $$| $$_  $$_  $$ /$$__  $$ \  $$$$/
| $$__  $$| $$  \ $$| $$| $$ \ $$ \ $$| $$$$$$$$  >$$  $$
| $$  | $$| $$  | $$| $$| $$ | $$ | $$| $$_____/ /$$/\  $$
| $$  | $$| $$  | $$| $$| $$ | $$ | $$|  $$$$$$$| $$  \ $$
|__/  |__/|__/  |__/|__/|__/ |__/ |__/ \_______/|__/  |__/
"""

    return banner_ascii


def get_version():
    __version__ = '0.1.7'
    return __version__


def get_search_result(search_item):
    """
        Searches for a given anime
    """
    search_url = "https://www.animeout.xyz/"
    params = {
        "s": search_item
    }
    r = requests.get(search_url, params=params)
    search_result_html = BeautifulSoup(r.text, "html.parser")

    search_result = []
    for i in search_result_html.findAll("h3", {"class": "post-title"}):
        search_result.append({
            "name": i.text,
            "url": i.find("a")["href"]
        })
    return search_result


def get_anime_episodes(anime_url):
    """
        Get the episodes in the anime by parsing all links that are videos
    """
    r = requests.get(anime_url)
    anime_result = BeautifulSoup(r.text, "html.parser")

    episodes = []
    for i in anime_result.findAll("a"):
        try:
            if i["href"][-3:] in ["mkv", "mp4]"]:
                episodes.append(i["href"])
        except:
            pass
    return episodes


def get_download_url(anime_url):
    """
        Get the video download URL
    """
    r = requests.get(anime_url)
    pre_download_page = BeautifulSoup(r.text, "html.parser")
    pre_download_url = pre_download_page.find("a", {"class": "btn"})["href"]

    r = requests.get(pre_download_url)
    download_page = BeautifulSoup(r.text, "html.parser")
    # using a try catch because .text returned empty on some OS
    try:
        download_url = download_page.find(
            "script", {"src": None}).text.split('"')[1]
    except:
        download_url = download_page.find(
            "script", {"src": None}).contents[0].split('"')[1]
    return download_url


def download_episode(anime_name, download_url):
    """
        Download anime and store in the folder the same name
        Don't download files that exist and clear tmp files after download
    """
    filename = os.path.basename(download_url)
    download_path = os.path.join(anime_name, filename)
    if not os.path.exists(download_path):
        print("\nDownloading", filename)
        wget.download(download_url, download_path)
        clear_tmp(anime_name)


def make_directory(anime_name):
    """
        Create folder to store anime
    """
    if not os.path.exists(anime_name):
        os.mkdir(anime_name)


def clear_tmp(directory):
    # clear tmp files
    for i in os.listdir(directory):
        if i[-3:] == "tmp":
            os.remove(os.path.join(directory, i))



import setuptools
import animeX.utils as utils

packages = [
    'animeX'
]

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="animeX",  # Replace with your own username
    version=utils.get_version(),
    author="Samuel Abada",
    author_email="abadasamuelosp@gmail.com",
    description="A simple, yet versatile package for downloading " \
                "anime.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mastersam07/animeX-pack",
    packages=setuptools.find_packages(),
    install_requires=[  # I get to this in a second
        "wget==3.2",
        "requests==2.21.0",
        "beautifulsoup4==4.9.0",
    ],
    classifiers=[
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Utilities",
        "Topic :: Internet",
        "Topic :: Multimedia :: Video"
    ],
    python_requires='>=3.6',
    keywords=["anime", "download", "video", ],
)
